==> haskell-prettyprinter-1.3.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter
version: 1.3.0
id: prettyprinter-1.3.0-HGmdufuPT6d13IPM0gvEQC
key: prettyprinter-1.3.0-HGmdufuPT6d13IPM0gvEQC
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: A modern, easy to use, well-documented, extensible pretty-printer.
description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md
category: User Interfaces, Text
abi: 85611a9bef4dfead427d8a64222cd4d9
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.ShowS
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-1.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/prettyprinter-1.3.0
hs-libraries: HSprettyprinter-1.3.0-HGmdufuPT6d13IPM0gvEQC
depends:
    base-4.12.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-1.3.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter
version: 1.3.0
id: prettyprinter-1.3.0-1vaULhcd5aX1fxtUiEYiL4
key: prettyprinter-1.3.0-1vaULhcd5aX1fxtUiEYiL4
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: A modern, easy to use, well-documented, extensible pretty-printer.
description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md
category: User Interfaces, Text
abi: 4b962cfbf0de08be24d431112d33cead
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.ShowS
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-1.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/prettyprinter-1.3.0
hs-libraries: HSprettyprinter-1.3.0-1vaULhcd5aX1fxtUiEYiL4
depends:
    base-4.12.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
